/**
 * ErrorBannerBuilder to build ErrorBanner
 * @public
 */
export class ErrorBannerBuilder {
    /**
     * Add dismissing action to ErrorBanner
     * @public
     * @param dismissingAction - {@link DismissingAction}
     * @returns
     */
    withDismissingAction(dismissingAction) {
        this.dismissingAction = dismissingAction;
        return this;
    }
    /**
     * Add confirming action to ErrorBanner
     * @public
     * @param confirmingAction - {@link ConfirmingAction}
     * @returns
     */
    withConfirmingAction(confirmingAction) {
        if (!this.confirmingActions) {
            this.confirmingActions = [];
        }
        this.confirmingActions.push(confirmingAction);
        return this;
    }
    /**
     * Build ErrorBanner
     * @public
     * @returns ErrorBanner
     */
    build() {
        let errorBanner = {};
        if (this.dismissingAction) {
            errorBanner = { dismissingAction: this.dismissingAction, ...errorBanner };
        }
        if (this.confirmingActions) {
            errorBanner = { confirmingActions: this.confirmingActions, ...errorBanner };
        }
        return errorBanner;
    }
}
/**
 * Get error banner builder instance
 * @public
 */
export const getErrorBannerBuilder = () => new ErrorBannerBuilder();
