/**
 * ErrorDialogBuilder class
 * @public
 */
export class ErrorDialogBuilder {
    /**
     * Add dismissing action to ErrorDialog
     * @public
     * @param dismissingAction - {@link DismissingAction}
     * @returns
     */
    withDismissingAction(dismissingAction) {
        this.dismissingAction = dismissingAction;
        return this;
    }
    /**
     * Add confirming action to ErrorDialog
     * @public
     * @param confirmingAction - {@link ConfirmingAction}
     * @returns
     */
    withConfirmingAction(confirmingAction) {
        if (!this.confirmingActions) {
            this.confirmingActions = [];
        }
        this.confirmingActions.push(confirmingAction);
        return this;
    }
    /**
     * Build ErrorDialog
     * @public
     * @returns ErrorDialog
     */
    build() {
        let errorDialog = {};
        if (this.dismissingAction) {
            errorDialog = { dismissingAction: this.dismissingAction, ...errorDialog };
        }
        if (this.confirmingActions) {
            errorDialog = { confirmingActions: this.confirmingActions, ...errorDialog };
        }
        return errorDialog;
    }
}
/**
 * Returns an instance of ErrorDialogBuilder
 * @public
 */
export const getErrorDialogBuilder = () => new ErrorDialogBuilder();
