import { getErrorContainer } from '../error-util';
/**
 * Shows the error notification
 * @internal
 * @param error - The ErrorStructure object
 * @param tagName - The tag name to create prefix for the design system provider & error component
 * @returns
 * */
export const showNotification = (error, tagName) => {
    const tagPrefix = tagName.split('-')[0];
    const container = getErrorContainer('notify-container', tagName);
    if (container) {
        container.style.position = 'fixed';
        switch (error?.config?.notification?.position) {
            case 'top-left':
                container.style.top = '0';
                container.style.left = '0';
                break;
            case 'bottom-left':
                container.style.bottom = '0';
                container.style.left = '0';
                break;
            case 'bottom-right':
                container.style.bottom = '0';
                container.style.right = '0';
                break;
            default:
                container.style.top = '0';
                container.style.right = '0';
        }
    }
    const toastNotify = document.createElement(`${tagPrefix}-toast`);
    const errorTitle = document.createElement('div');
    errorTitle.setAttribute('slot', 'top');
    errorTitle.textContent = error.title ?? 'Error';
    const errorDetails = document.createElement('div');
    errorDetails.setAttribute('slot', 'content');
    errorDetails.textContent = error?.errorDetails || '';
    const errorDate = document.createElement('div');
    errorDate.setAttribute('slot', 'date');
    errorDate.textContent = new Date().toLocaleTimeString();
    toastNotify.setAttribute('notify', error?.config?.notification?.type || '');
    error?.config?.notification?.autoClose
        ? toastNotify.setAttribute('auto-close', `${error?.config?.notification?.autoClose}`)
        : '';
    error?.config?.notification?.closeTimeout
        ? toastNotify.setAttribute('close-timeout', `${error?.config?.notification?.closeTimeout}`)
        : '';
    toastNotify.appendChild(errorTitle);
    toastNotify.appendChild(errorDetails);
    toastNotify.appendChild(errorDate);
    container.appendChild(toastNotify);
};
